removes every json and qs2 files found by sourcoise_status() unless a specific tibble (filtered from sourcoise_status()) is passed as an argument.
Arguments
- what2keep
(–) a string (such as "last", the default or "nothing" clears all or "all" removes only non sourcoise files) or a tibble such as the one obtained by
sourcoise_status(), possibly filtered for the files you whish to keep- root
to force root, not recommended (expert use only)
Value
list of cleared files, plus a side-effect as specified cache files are deleted (no undo possible)
See also
Other sourcoise:
sourcoise(),
sourcoise_clear_all(),
sourcoise_refresh(),
sourcoise_reset(),
sourcoise_status()
Examples
if (FALSE) { # rlang::is_installed("insee")
dir <- tempdir()
set_sourcoise_root(dir)
fs::file_copy(
fs::path_package("sourcoise", "some_data.R"),
dir,
overwrite = TRUE)
# Force execution
data <- sourcoise("some_data.R", force_exec = TRUE)
# we then clear all caches
sourcoise_clear()
sourcoise_status()
}