src: path to the source file (r script)
date: last execution date
valid: is cache valid ?
uid: id of user
index: index of cache
timing: last execution timing
size: size of the R object(s) returned
lapse: periodic refresh trigger
wd: wd setting for execution of r script
args: arguments passed to R script
json_file: path to the file keeping cache information
qmd_file: list of path to qmd files calling this script (relevant only for quarto projects)
src_in: localisation of cache option
data_file: path to data cached
data_date: date and time of last save of data
log_file: path to log file, if logging activated
root: path to the project root, used as reference for all paths
scr_hash: hash of the source file
track_hash: hash of the tracked files, if any
track: list of files tracked
args_hash: hash of arguments
data_hash: hash of data cached